==> 0.9.0&file=out_yasapi-0.9.0-src.tar.gz: out_yasapi-0.9.0/out_yasapi/yasapi_channel_options.c <==
/*
 * yasapi_payer_options.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static const Property gcaChannelPropertyList[]={
  { L"share_mode",&gcIntType,offsetof(ChannelOptions,eShareMode),0 },
  { L"autoconvertpcm",&gcIntType,offsetof(ChannelOptions,bAutoConvertPCM),0 },
  { L"src_default_quality",&gcIntType,
      offsetof(ChannelOptions,bSRCDefaultQuality),0 },
  { L"pull",&gcIntType,offsetof(ChannelOptions,bPull),0 },
  { L"ring_size",&gcDoubleType,offsetof(ChannelOptions,qRingSize),0 },
  { L"ring_fill",&gcDoubleType,offsetof(ChannelOptions,qRingFill),0 },
  { L"share_size",&gcDoubleType,offsetof(ChannelOptions,qShareSize),0 },
  { NULL,NULL,0,0 }
};

///////////////////////////////////////////////////////////////////////////////
int ChannelOptionsCreate(ChannelOptions *pOptions, Channel *pChannel)
{
  const double qMaxRingSize=(double)CUST_SLIDER_MAX/CUST_SLIDER_SCALE;
  Plugin *pPlugin=pChannel->pPlayer->pPlugin;
  PropertyLoadConfig c;

  /////////////////////////////////////////////////////////////////////////////
  pOptions->pChannel=pChannel;

  /////////////////////////////////////////////////////////////////////////////
  c.debug=pPlugin->options.debug;
  c.path=pPlugin->options.path;
  c.pData=pOptions;
  c.pDefault=ChannelOptionsDefault();
  c.group=pChannel->pstrId;
  c.pfx=L"    ";
  PropertyLoad(gcaChannelPropertyList,&c);

  if (qMaxRingSize<pOptions->qRingSize)
    pOptions->qRingSize=qMaxRingSize;

  if (pOptions->qRingSize<pOptions->qRingFill)
    pOptions->qRingFill=pOptions->qRingSize;

  if (pOptions->qRingFill<pOptions->qShareSize)
    pOptions->qShareSize=pOptions->qRingFill;

  /////////////////////////////////////////////////////////////////////////////
  return 0;
}

void ChannelOptionsDestroy(ChannelOptions *pOptions)
{
}

///////////////////////////////////////////////////////////////////////////////
void ChannelOptionsSave(ChannelOptions *pOptions)
{
  Channel *pChannel=pOptions->pChannel;
  PropertySaveConfig c;

  c.path=pChannel->pPlayer->pPlugin->options.path;
  c.pData=pOptions;
  c.group=pChannel->pstrId;
  PropertySave(gcaChannelPropertyList,&c);
}

///////////////////////////////////////////////////////////////////////////////
const ChannelOptions *ChannelOptionsDefault(void)
{
  static int initialized;
  static ChannelOptions options;

  if (!initialized) {
    options.eShareMode=YASAPI_SHAREMODE_EXCLUSIVE;
    options.bAutoConvertPCM=TRUE;
    options.bSRCDefaultQuality=FALSE;
    options.bPull=FALSE;
    options.qShareSize=1.0;
    options.qRingFill=1.0;
    options.qRingSize=1.5;

    initialized=1;
  }

  return &options;
}

==> 0.10.0&file=out_yasapi-0.10.0-src.tar.gz: out_yasapi-0.10.0/out_yasapi/yasapi_channel_options.c <==
/*
 * yasapi_channel_options.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static const Property gcaChannelPropertyList[]={
  { L"share_mode",&gcIntType,offsetof(ChannelOptions,eShareMode),0 },
  { L"device_period",&gcIntType,offsetof(ChannelOptions,eDevicePeriod),0 },
  { L"autoconvertpcm",&gcIntType,offsetof(ChannelOptions,bAutoConvertPCM),0 },
  { L"src_default_quality",&gcIntType,
      offsetof(ChannelOptions,bSRCDefaultQuality),0 },
  { L"pull",&gcIntType,offsetof(ChannelOptions,bPull),0 },
  { L"balance",&gcIntType,offsetof(ChannelOptions,bBalance),0 },
  { L"balance_start",&gcDoubleType,offsetof(ChannelOptions,qBalanceStart),0 },
  { L"ring_size",&gcDoubleType,offsetof(ChannelOptions,qRingSize),0 },
  { L"ring_fill",&gcDoubleType,offsetof(ChannelOptions,qRingFill),0 },
  { L"share_size",&gcDoubleType,offsetof(ChannelOptions,qShareSize),0 },
  { NULL,NULL,0,0 }
};

///////////////////////////////////////////////////////////////////////////////
int ChannelOptionsCreate(ChannelOptions *pOptions, Channel *pChannel)
{
  Plugin *pPlugin=pChannel->pPlayer->pPlugin;
  PropertyLoadConfig c;

  /////////////////////////////////////////////////////////////////////////////
  pOptions->pChannel=pChannel;

  /////////////////////////////////////////////////////////////////////////////
  c.debug=pPlugin->options.debug;
  c.path=pPlugin->options.path;
  c.pData=pOptions;
  c.pDefault=ChannelOptionsDefault();
  c.group=pChannel->pstrId;
  c.pfx=L"    ";
  PropertyLoad(gcaChannelPropertyList,&c);

  if (YASAPI_MAX_RING_SIZE<pOptions->qRingSize)
    pOptions->qRingSize=YASAPI_MAX_RING_SIZE;

  if (pOptions->qRingSize<pOptions->qRingFill)
    pOptions->qRingFill=pOptions->qRingSize;

  if (pOptions->qRingFill<pOptions->qShareSize)
    pOptions->qShareSize=pOptions->qRingFill;

  /////////////////////////////////////////////////////////////////////////////
  return 0;
}

void ChannelOptionsDestroy(ChannelOptions *pOptions)
{
}

///////////////////////////////////////////////////////////////////////////////
void ChannelOptionsSave(ChannelOptions *pOptions)
{
  Channel *pChannel=pOptions->pChannel;
  PropertySaveConfig c;

  c.path=pChannel->pPlayer->pPlugin->options.path;
  c.pData=pOptions;
  c.group=pChannel->pstrId;
  PropertySave(gcaChannelPropertyList,&c);
}

///////////////////////////////////////////////////////////////////////////////
const ChannelOptions *ChannelOptionsDefault(void)
{
  static int initialized;
  static ChannelOptions options;

  if (!initialized) {
    options.eShareMode=YASAPI_SHAREMODE_EXCLUSIVE;
    options.eDevicePeriod=YASAPI_DEVICE_PERIOD_DEFAULT;
    options.bAutoConvertPCM=TRUE;
    options.bSRCDefaultQuality=FALSE;
    options.bPull=FALSE;
    options.bBalance=FALSE;
    options.qBalanceStart=0.5;
    options.qShareSize=7.0;
    options.qRingSize=1.5;
    options.qRingFill=1.0;

    initialized=1;
  }

  return &options;
}
